# Controller
#
# Implements a basic structure for a Shot MVC Controller
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/


class Controller
	# Application instance to which the controller belongs
	attr_accessor :app

	# An array of actions which can not be called from a view
	attr_accessor :view_private

	# Instantiate the controller and keep track of the passed ApplicationInstance

	def initialize(app)
		@view_private = []
		@app = app
	end

	# Adds an action to the list of private, non-view-callable actions
	#
	# == Attributes
	#
	# * +action+ - String name of a controller method

	def add_private_action(action)
		view_private.push action
	end

	# Utilize a Loader.
	#
	# Note:: This is a convenient access method for ApplicationInstance#get

	def get(type, name)
		@app.get type, name
	end

	# Instantiate a new Element, assigned to the specified query
	#
	# Note:: Sugary way of writing +get "element", "selector"+

	def e(selector)
		@app.get 'element', selector
	end
end