# ControllerDelegate
#
# Allows you to perform various actions on controllers, including creating, deleting,
# and modifying them.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'erb'

require_relative './controller_not_found_exception'

class ControllerDelegate
	def self.create_controller(controller_name, *actions)
		template = <<eof
require 'shot_mvc'

class #{controller_name}Controller < Controller
  def setup()

  end
  <% actions.each do |action| %>
  def <%=action%>

  end
  <% end %>
end
eof

		template = ERB.new template
		File.write "app/controllers/#{controller_name.underscore}_controller.rb", template.result(binding)
	end

	def delete_controller(controller_name)
		if File.exists? "app/controllers/#{controller_name.underscore}_controller.rb"
			File.unlink "app/controllers/#{controller_name.underscore}_controller.rb"
		else
			raise ControllerNotFoundException.new "Could not find controller named #{controller_name}"
		end
	end
end