# ControllerRouter
#
# Routes incoming clients and handles their controller calls.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'shot'
require_relative './controller_load_exception'

class ControllerRouter < Router
	def initialize(client)
		super(client)

		client.on 'call_controller_action' do |data|
			controller = data['controller']
			if controller.include? 'GemRoot' then controller['GemRoot'] = gem_root end

			action = data['action']
			data = (data['data'] or nil)

			controller = @client.get 'controller', controller

			if controller.view_private.include? action then
				raise ControllerLoadException.new "#{controller}##{action} is not view accessible."
			end

			if data then controller.send(action, data) else controller.send(action) end
		end
	end

	private

	def gem_root
		Gem::Specification.find_by_name('shot_mvc').gem_dir
	end
end