# Element
#
# Represents an element on the user's page, with a corresponding jQuery
# selector which can be used to call jQuery functions on the user's page.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/


class Element
	# jQuery Selector
	attr_accessor :selector

	# Associated ApplicationInstance
	attr_accessor :app

	def self.from_app_and_selector(app, selector)
		element = Element.new selector
		element.app = app
		element
	end

	def initialize(selector)
		@selector = selector
		@app = nil
	end

	def jq(method, parameters = {})
		unless app == nil
			@app.emit 'jq', {
					'selector'    => @selector,
					'method'      => method,
					'parameters'  => [parameters]
			}
		end
	end

	def html=(html)
		self.jq 'html', [html]
	end

	def text=(text)
		self.jq 'text', [text]
	end

	def render(template, data = nil)
		template = @app.get 'template', template
		template.data = data unless data == nil
		self.html = template.render
	end
end