# SessionRouter
#
# Allows the application to modify session data for the client.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/

require 'shot'
require 'json'

class ApplicationInstance
	def session_get(key)
		@config[:session] = (@config[:session] or {})
		@config[:session][key]
	end

	def session_set(key, value)
		@config[:session] = (@config[:session] or {})
		@config[:session][key] = value
		session_save
	end

	def session_save
		File.write "app/sessions/#{@config[:session_key]}.json", @config[:session].to_json
	end
end

class SessionRouter < Router
	def initialize(client)
		super(client)

		client.on 'session_key' do |key|
			create_session_folder unless Dir.exists? 'app/sessions'
			create_session_file key unless File.exists? "app/sessions/#{key}.json"

			client.config[:session_key] = key
			client.config[:session] = JSON.parse File.read "app/sessions/#{key}.json"

			client.emit 'session_ready'
		end

		client.on 'request_session_key' do
			session_key = SecureRandom.uuid
			client.emit 'assign_session_key', :key => session_key, :session_hash => client.config['server']['Security']['SessionHash']

			create_session_folder unless Dir.exists? 'app/sessions'
			create_session_file session_key unless File.exists? "app/sessions/#{session_key}.json"

			client.config[:session_key] = session_key
			client.config[:session] = JSON.parse File.read "app/sessions/#{session_key}.json"

			client.emit 'session_ready'
		end

		client.emit 'provide_session_key', client.config['server']['Security']['SessionHash']
	end

	private

	def create_session_folder
		Dir.mkdir 'app/sessions'
	end

	def create_session_file(key)
		File.write "app/sessions/#{key}.json", '{}'
	end
end