# TemplateLoader
#
# Parses and loads ERB templates from the 'application/views' folder if
# it exists. If the folder does not exist, an exception will be raised.
#
# Shot Framework - Copyright (c) Jesse Aaron Dunlap <me@jessedunlap.me>
# Licensed under the MIT License. For full licensing information, please
# see LICENSE.md. http://github.com/JesseDunlap/shot/


require 'shot'
require 'erb'

require_relative './template'
require_relative './template_load_exception'

class TemplateLoader < Loader
	def initialize(client)
		super(client)
		@type = 'template'
	end

	def get(name)
		if template_exists? name
			if full_path? name
				Template.new name
			else
				Template.new "./app/views/#{name}.erb"
			end
		else
			if @client.config['server']['Security']['VisualErrors'] then
				begin
					raise TemplateLoadException.new "Could not load #{name}. Verify it exists at app/views/#{name}.erb"
				rescue Exception => ex
					template = Template.new "#{gem_root}/app/views/view_not_found.erb"
					template.data = { :requested_view => name, :exception => ex }
					return template
				end
			else
				raise TemplateLoadException.new "Could not load #{name}. Verify it exists at app/views/#{name}.erb"
			end
		end
	end

	private

	def gem_root
		 Gem::Specification.find_by_name('shot_mvc').gem_dir
	end

	def full_path?(view_name)
		File.exists? view_name
	end

	def template_exists?(view_name)
		File.exists? view_name or File.exists? "app/views/#{view_name}.erb"
	end
end